import escapeId from './escape-id';

const dropReadModel = async (pool, readModelName) => {
  const {
    targetEventStore,
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn
  } = pool;
  const {
    dbClusterOrInstanceArn: eventStoreClusterArn = dbClusterOrInstanceArn,
    awsSecretStoreArn: eventStoreSecretArn = awsSecretStoreArn,
    databaseName: eventStoreDatabaseName,
    eventsTableName: eventStoreEventsTableName = 'events',
    secretsTableName: eventStoreSecretsTableName = 'secrets'
  } = targetEventStore;
  const eventStoreDatabaseNameAsId = escapeId(eventStoreDatabaseName);
  const eventStoreSecretsTableNameAsId = escapeId(eventStoreSecretsTableName);
  const eventStoreEventsTableAsId = escapeId(eventStoreEventsTableName);
  const eventStoreThreadsTableAsId = escapeId(`${eventStoreEventsTableName}-threads`);
  const statements = [`TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreEventsTableAsId}`, `TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreThreadsTableAsId}`, `TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreSecretsTableNameAsId}`, `INSERT INTO ${eventStoreDatabaseNameAsId}.${eventStoreThreadsTableAsId}(
      "threadId",
      "threadCounter"
    ) VALUES ${Array.from(new Array(256)).map((_, index) => `(${index}, 0)`).join(',')}`];

  for (const statement of statements) {
    await rdsDataService.executeStatement({
      resourceArn: eventStoreClusterArn,
      secretArn: eventStoreSecretArn,
      database: 'postgres',
      sql: statement
    });
  }
};

export default dropReadModel;
//# sourceMappingURL=drop-read-model.js.map