"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _escapeId = _interopRequireDefault(require("./escape-id"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropReadModel = async (pool, readModelName) => {
  const {
    targetEventStore,
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn
  } = pool;
  const {
    dbClusterOrInstanceArn: eventStoreClusterArn = dbClusterOrInstanceArn,
    awsSecretStoreArn: eventStoreSecretArn = awsSecretStoreArn,
    databaseName: eventStoreDatabaseName,
    eventsTableName: eventStoreEventsTableName = 'events',
    secretsTableName: eventStoreSecretsTableName = 'secrets'
  } = targetEventStore;
  const eventStoreDatabaseNameAsId = (0, _escapeId.default)(eventStoreDatabaseName);
  const eventStoreSecretsTableNameAsId = (0, _escapeId.default)(eventStoreSecretsTableName);
  const eventStoreEventsTableAsId = (0, _escapeId.default)(eventStoreEventsTableName);
  const eventStoreThreadsTableAsId = (0, _escapeId.default)(`${eventStoreEventsTableName}-threads`);
  const statements = [`TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreEventsTableAsId}`, `TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreThreadsTableAsId}`, `TRUNCATE ${eventStoreDatabaseNameAsId}.${eventStoreSecretsTableNameAsId}`, `INSERT INTO ${eventStoreDatabaseNameAsId}.${eventStoreThreadsTableAsId}(
      "threadId",
      "threadCounter"
    ) VALUES ${Array.from(new Array(256)).map((_, index) => `(${index}, 0)`).join(',')}`];

  for (const statement of statements) {
    await rdsDataService.executeStatement({
      resourceArn: eventStoreClusterArn,
      secretArn: eventStoreSecretArn,
      database: 'postgres',
      sql: statement
    });
  }
};

var _default = dropReadModel;
exports.default = _default;
//# sourceMappingURL=drop-read-model.js.map