"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _types = require("./types");

var _rawExecuteStatement = _interopRequireDefault(require("./raw-execute-statement"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const status = async (pool, readModelName) => {
  const {
    escapeId,
    escapeStr,
    targetEventStore,
    rdsDataService,
    coercer
  } = pool;
  const {
    dbClusterOrInstanceArn: eventStoreClusterArn,
    awsSecretStoreArn: eventStoreSecretArn,
    databaseName: eventStoreDatabaseName,
    eventsTableName: eventStoreEventsTableName = 'events'
  } = targetEventStore;
  const eventStoreDatabaseNameAsString = escapeStr(eventStoreDatabaseName);
  const eventStorePauseTableNameAsString = escapeStr(`${eventStoreEventsTableName}-pause`);
  const eventStoreDatabaseNameAsId = escapeId(eventStoreDatabaseName);
  const eventStoreEventsTableAsId = escapeId(eventStoreEventsTableName);
  const pauseCheckPromise = (0, _rawExecuteStatement.default)(rdsDataService, eventStoreClusterArn, eventStoreSecretArn, coercer, `SELECT EXISTS (
          SELECT FROM information_schema.tables 
          WHERE  table_schema = ${eventStoreDatabaseNameAsString}
          AND    table_name   = ${eventStorePauseTableNameAsString}
         ) AS "pauseCheck"
    `);
  const eventsPromise = (0, _rawExecuteStatement.default)(rdsDataService, eventStoreClusterArn, eventStoreSecretArn, coercer, `SELECT "threadCounter", "threadId", "type", "timestamp", "aggregateId", "aggregateVersion", "payload"
        FROM ${eventStoreDatabaseNameAsId}.${eventStoreEventsTableAsId}
        ORDER BY "timestamp" DESC, "threadCounter" DESC, "threadId" DESC
        LIMIT 1
    `);
  const check = await pauseCheckPromise;
  let status = _types.ReadModelRunStatus.DELIVER;
  if (check && check.length && check[0].pauseCheck) status = _types.ReadModelRunStatus.SKIP;
  const events = await eventsPromise;
  let lastEvent;

  if (events.length) {
    let payload;

    try {
      payload = JSON.parse(events[0].payload);
    } catch (error) {
      payload = {};
    }

    lastEvent = {
      threadCounter: events[0].threadCounter,
      threadId: events[0].threadId,
      type: events[0].type,
      timestamp: events[0].timestamp,
      aggregateId: events[0].aggregateId,
      aggregateVersion: events[0].aggregateVersion,
      payload
    };
  } else {
    lastEvent = {
      type: 'Init'
    };
  }

  const result = {
    eventSubscriber: '',
    deliveryStrategy: 'inline-ledger',
    successEvent: lastEvent,
    failedEvent: null,
    errors: null,
    cursor: null,
    status: status
  };
  return result;
};

var _default = status;
exports.default = _default;
//# sourceMappingURL=status.js.map