/// <reference types="node" />
import type { ObjectFunctionLikeKeys, CommonAdapterPool, CommonAdapterOptions, AdapterOperations, AdapterConnection, AdapterImplementation, StoreApi, PerformanceTracerLike, OmitObject, JsonPrimitive, FunctionLike, UnPromise } from '@resolve-js/readmodel-base';
import type RDSDataService from 'aws-sdk/clients/rdsdataservice';
import type crypto from 'crypto';
export * from '@resolve-js/readmodel-base';
export declare type LibDependencies = {
    RDSDataService: typeof RDSDataService;
    crypto: typeof crypto;
};
export declare type FullJitterMethod = (retries: number) => Promise<void>;
export declare type EscapeableMethod = (str: string) => string;
export declare type IsRdsServiceErrorMethod = (error: Error & {
    code: string | number;
    stack: string;
}) => boolean;
export declare type DropReadModelMethod = (pool: AdapterPool, readModelName: string) => Promise<void>;
export declare type HighloadMethodParameters<KS extends ObjectFunctionLikeKeys<InstanceType<LibDependencies['RDSDataService']>>, T extends {
    [K in KS]: FunctionLike;
}> = T[KS] extends {
    (params: infer Params, callback: infer Callback): infer Result;
    (callback: infer _Callback): infer _Result;
} ? Params : never;
export declare type HighloadMethodReturnType<KS extends ObjectFunctionLikeKeys<InstanceType<LibDependencies['RDSDataService']>>, T extends {
    [K in KS]: FunctionLike;
}> = Promise<T[KS] extends {
    (params: infer Params, callback: infer Callback): infer Result;
    (callback: infer _Callback): infer _Result;
} ? Result extends {
    promise: infer F;
} ? F extends FunctionLike ? UnPromise<ReturnType<F>> : never : never : never>;
export declare type WrapHighloadMethod = <KS extends ObjectFunctionLikeKeys<InstanceType<LibDependencies['RDSDataService']>>, T extends {
    [K in KS]: FunctionLike;
}>(isHighloadError: IsRdsServiceErrorMethod, obj: T, method: KS, params: HighloadMethodParameters<KS, T>) => HighloadMethodReturnType<KS, T>;
export declare type HighloadRdsMethod<KS extends ObjectFunctionLikeKeys<InstanceType<LibDependencies['RDSDataService']>>> = (...args: [
    HighloadMethodParameters<KS, InstanceType<LibDependencies['RDSDataService']>>
]) => HighloadMethodReturnType<KS, InstanceType<LibDependencies['RDSDataService']>>;
export declare type HighloadRdsDataService = {
    executeStatement: HighloadRdsMethod<'executeStatement'>;
};
declare type TargetEventStore = {
    dbClusterOrInstanceArn: string;
    awsSecretStoreArn: string;
    databaseName: string;
    eventsTableName?: string;
    secretsTableName?: string;
};
export declare type AdapterOptions = CommonAdapterOptions & {
    dbClusterOrInstanceArn: RDSDataService.Arn;
    awsSecretStoreArn: RDSDataService.Arn;
    databaseName: RDSDataService.DbName;
    targetEventStore: TargetEventStore;
} & RDSDataService.ClientConfiguration;
export declare type InternalMethods = {
    isHighloadError: IsRdsServiceErrorMethod;
    dropReadModel: DropReadModelMethod;
    escapeId: EscapeableMethod;
    escapeStr: EscapeableMethod;
    coercer: CoercerMethod;
};
export declare type ArrayOrSingleOrNull<T> = Array<T> | T | null;
export declare type CoercerMethod = (value: {
    intValue?: number;
    stringValue?: string;
    bigIntValue?: number;
    longValue?: number;
    booleanValue?: boolean;
    isNull?: boolean;
}) => JsonPrimitive;
export declare type AdapterPool = CommonAdapterPool & {
    performanceTracer: PerformanceTracerLike;
    rdsDataService: HighloadRdsDataService;
    dbClusterOrInstanceArn: RDSDataService.Arn;
    awsSecretStoreArn: RDSDataService.Arn;
    targetEventStore: TargetEventStore;
} & {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterOperations<AdapterPool>[K];
} & {
    [K in keyof StoreApi<CommonAdapterPool>]: StoreApi<AdapterPool>[K];
} & InternalMethods;
export declare type CurrentAdapterConnection = AdapterConnection<AdapterPool, OmitObject<AdapterOptions, CommonAdapterPool>>;
export declare type ExternalMethods = {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterPool[K];
};
export declare type CurrentStoreApi = {
    [K in keyof StoreApi<CommonAdapterPool>]: AdapterPool[K];
};
export declare type ConnectionDependencies = LibDependencies & InternalMethods & ExternalMethods & CurrentStoreApi;
export declare type CurrentConnectMethod = (imports: ConnectionDependencies, ...args: Parameters<CurrentAdapterConnection['connect']>) => ReturnType<CurrentAdapterConnection['connect']>;
export declare type CurrentDisconnectMethod = CurrentAdapterConnection['disconnect'];
export declare type CurrentAdapterImplementation = AdapterImplementation<AdapterPool, AdapterOptions>;
